@@ -11,8 +11,6 @@
 
 #undef arma_hot
 #undef arma_cold
-#undef arma_pure
-#undef arma_const
 #undef arma_aligned
 #undef arma_align_mem
 #undef arma_warn_unused
@@ -24,8 +22,6 @@
 
 #define arma_hot
 #define arma_cold
-#define arma_pure
-#define arma_const
 #define arma_aligned
 #define arma_align_mem
 #define arma_warn_unused
@@ -35,6 +31,11 @@
 #define arma_noinline
 #define arma_ignore(variable)  ((void)(variable))
 
+// arma_pure and arma_const kept only for compatibility with old code
+#undef  arma_pure
+#define arma_pure
+#undef  arma_const
+#define arma_const
 
 #undef arma_fortran_noprefix
 #undef arma_fortran_prefix
@@ -87,7 +88,7 @@
   
   #if defined(ARMA_64BIT_WORD) && defined(SIZE_MAX)
     #if (SIZE_MAX < 0xFFFFFFFFFFFFFFFFull)
-      #pragma message ("WARNING: disabled use of 64 bit integers, as std::size_t is smaller than 64 bits")
+      // #pragma message ("WARNING: disabled use of 64 bit integers, as std::size_t is smaller than 64 bits")
       #undef ARMA_64BIT_WORD
     #endif
   #endif
@@ -139,7 +140,7 @@
 #endif
 
 
-#if defined(__MINGW32__)
+#if defined(__MINGW32__) || defined(__CYGWIN__) || defined(_MSC_VER)
   #undef ARMA_HAVE_POSIX_MEMALIGN
 #endif
 
@@ -181,8 +182,6 @@
   
   #define ARMA_GOOD_COMPILER
   
-  #undef  arma_pure
-  #undef  arma_const
   #undef  arma_aligned
   #undef  arma_align_mem
   #undef  arma_warn_unused
@@ -191,8 +190,6 @@
   #undef  arma_inline
   #undef  arma_noinline
   
-  #define arma_pure               __attribute__((__pure__))
-  #define arma_const              __attribute__((__const__))
   #define arma_aligned            __attribute__((__aligned__))
   #define arma_align_mem          __attribute__((__aligned__(16)))
   #define arma_warn_unused        __attribute__((__warn_unused_result__))
@@ -206,7 +203,7 @@
   
   #if defined(ARMA_USE_CXX11)
     #if (ARMA_GCC_VERSION < 40800)
-      #pragma message ("WARNING: compiler is in C++11 mode, but it has incomplete support for C++11 features;")
+      #pragma message ("WARNING: compiler is in C++11 mode, but it has INCOMPLETE support for C++11 features;")
       #pragma message ("WARNING: if something breaks, you get to keep all the pieces.")
       #pragma message ("WARNING: to forcefully prevent Armadillo from using C++11 features,")
       #pragma message ("WARNING: #define ARMA_DONT_USE_CXX11 before #include <armadillo>")
@@ -266,16 +263,6 @@
     #define __has_attribute(x) 0
   #endif
   
-  #if __has_attribute(__pure__)
-    #undef  arma_pure
-    #define arma_pure __attribute__((__pure__))
-  #endif
-  
-  #if __has_attribute(__const__)
-    #undef  arma_const
-    #define arma_const __attribute__((__const__))
-  #endif
-  
   #if __has_attribute(__aligned__)
     #undef  arma_aligned
     #undef  arma_align_mem
@@ -363,14 +350,14 @@
   #endif
   
   #if (_MSC_VER < 1700)
-    #pragma message ("WARNING: this compiler is outdated and has incomplete support for the C++ standard;")
+    #pragma message ("WARNING: this compiler is OUTDATED and has INCOMPLETE support for the C++ standard;")
     #pragma message ("WARNING: if something breaks, you get to keep all the pieces")
     #define ARMA_BAD_COMPILER
   #endif
   
   #if defined(ARMA_USE_CXX11)
     #if (_MSC_VER < 1900)
-      #pragma message ("WARNING: compiler is in C++11 mode, but it has incomplete support for C++11 features;")
+      #pragma message ("WARNING: compiler is in C++11 mode, but it has INCOMPLETE support for C++11 features;")
       #pragma message ("WARNING: if something breaks, you get to keep all the pieces.")
       #pragma message ("WARNING: to forcefully prevent Armadillo from using C++11 features,")
       #pragma message ("WARNING: #define ARMA_DONT_USE_CXX11 before #include <armadillo>")
