@@ -88,7 +88,7 @@ sp_auxlib::eigs_sym(Col<eT>& eigval, Mat<eT>& eigvec, const SpBase<eT, T1>& X, c
     arma_debug_check( (n_eigvals >= p.get_n_rows()), "eigs_sym(): n_eigvals must be less than the number of rows in the matrix" );
     
     // If the matrix is empty, the case is trivial.
-    if(p.get_n_cols() == 0) // We already know n_cols == n_rows.
+    if( (p.get_n_cols() == 0) || (n_eigvals == 0) ) // We already know n_cols == n_rows.
       {
       eigval.reset();
       eigvec.reset();
@@ -197,7 +197,7 @@ sp_auxlib::eigs_gen(Col< std::complex<T> >& eigval, Mat< std::complex<T> >& eigv
     arma_debug_check( (n_eigvals + 1 >= p.get_n_rows()), "eigs_gen(): n_eigvals + 1 must be less than the number of rows in the matrix" );
     
     // If the matrix is empty, the case is trivial.
-    if(p.get_n_cols() == 0) // We already know n_cols == n_rows.
+    if( (p.get_n_cols() == 0) || (n_eigvals == 0) ) // We already know n_cols == n_rows.
       {
       eigval.reset();
       eigvec.reset();
@@ -349,7 +349,7 @@ sp_auxlib::eigs_gen(Col< std::complex<T> >& eigval, Mat< std::complex<T> >& eigv
     arma_debug_check( (n_eigvals + 1 >= p.get_n_rows()), "eigs_gen(): n_eigvals + 1 must be less than the number of rows in the matrix" );
     
     // If the matrix is empty, the case is trivial.
-    if(p.get_n_cols() == 0) // We already know n_cols == n_rows.
+    if( (p.get_n_cols() == 0) || (n_eigvals == 0) ) // We already know n_cols == n_rows.
       {
       eigval.reset();
       eigvec.reset();
